@@ -26,7 +26,6 @@
 #include "panel-action-button.h"
 #include "panel-toplevel.h"
 #include "panel-util.h"
-#include "panel-menu-button.h"
 #include "panel-layout.h"
 #include "panel-lockdown.h"
 #include "panel-schemas.h"
@@ -50,10 +49,6 @@ panel_applet_set_dnd_enabled (AppletInfo *info,
 			      gboolean    dnd_enabled)
 {
 	switch (info->type) {
-	case PANEL_OBJECT_MENU:
-		panel_menu_button_set_dnd_enabled (PANEL_MENU_BUTTON (info->widget),
-						   dnd_enabled);
-		break;
 	case PANEL_OBJECT_LAUNCHER:
 		panel_launcher_set_dnd_enabled (info->data, dnd_enabled);
 		break;
@@ -168,10 +163,6 @@ applet_callback_callback (GtkWidget      *widget,
 		else if (!strcmp (menu->name, "properties"))
 			launcher_properties (menu->info->data);
 		break;
-	case PANEL_OBJECT_MENU:
-		panel_menu_button_invoke_menu (
-			PANEL_MENU_BUTTON (menu->info->widget), menu->name);
-		break;
 	case PANEL_OBJECT_ACTION:
 		panel_action_button_invoke_menu (
 			PANEL_ACTION_BUTTON (menu->info->widget), menu->name);
@@ -493,94 +484,15 @@ panel_applet_get_edit_menu (AppletInfo *info)
 	return info->edit_menu;
 }
 
-void
-panel_applet_position_menu (GtkMenu   *menu,
-			    int       *x,
-			    int       *y,
-			    gboolean  *push_in,
-			    GtkWidget *applet)
-{
-	GtkAllocation   allocation;
-	GtkRequisition  requisition;
-	GdkSeat        *seat;
-	GdkDevice      *device;
-	GdkScreen      *screen;
-	GtkWidget      *parent;
-	int             menu_x = 0;
-	int             menu_y = 0;
-	int             pointer_x;
-	int             pointer_y;
-	int             monitor_num;
-	GdkRectangle    monitor_rect;
-
-	parent = gtk_widget_get_parent (applet);
-
-	g_return_if_fail (PANEL_IS_WIDGET (parent));
-
-	screen = gtk_widget_get_screen (applet);
-
-	gtk_widget_get_preferred_size (GTK_WIDGET (menu), &requisition, NULL);
-	gdk_window_get_origin (gtk_widget_get_window (applet), &menu_x, &menu_y);
-
-	seat = gdk_display_get_default_seat (gtk_widget_get_display (applet));
-	device = gdk_seat_get_pointer (seat);
-
-	gdk_window_get_device_position(gtk_widget_get_window (applet), device, &pointer_x, &pointer_y, NULL);
-
-	gtk_widget_get_allocation (applet, &allocation);
-
-	if (!gtk_widget_get_has_window (applet)) {
-		menu_x += allocation.x;
-		menu_y += allocation.y;
-	}
-
-	monitor_num = gdk_screen_get_monitor_at_point (screen,menu_x,menu_y);
-	gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor_rect);
-
-	if (PANEL_WIDGET (parent)->orient == GTK_ORIENTATION_HORIZONTAL) {
-		if (gtk_widget_get_direction (GTK_WIDGET (menu)) != GTK_TEXT_DIR_RTL) {
-			if (pointer_x < allocation.width &&
-			    requisition.width < pointer_x)
-				menu_x += MIN (pointer_x,
-					       allocation.width - requisition.width);
-		} else {
-			menu_x += allocation.width - requisition.width;
-			if (pointer_x > 0 && pointer_x < allocation.width &&
-			    pointer_x < allocation.width - requisition.width) {
-				menu_x -= MIN (allocation.width - pointer_x,
-					       allocation.width - requisition.width);
-			}
-		}
-		menu_x = MIN (menu_x, monitor_rect.x + monitor_rect.width - requisition.width);
-
-		if (menu_y > monitor_rect.y + (monitor_rect.height / 2))
-			menu_y -= requisition.height;
-		else
-			menu_y += allocation.height;
-	} else {
-		if (pointer_y < allocation.height &&
-		    requisition.height < pointer_y)
-			menu_y += MIN (pointer_y, allocation.height - requisition.height);
-		menu_y = MIN (menu_y, monitor_rect.y +monitor_rect.height - requisition.height);
-
-		if (menu_x > monitor_rect.x + (monitor_rect.width / 2))
-			menu_x -= requisition.width;
-		else
-			menu_x += allocation.width;
-	}
-
-	*x = menu_x;
-	*y = menu_y;
-	*push_in = FALSE;
-}
-
 static void
-applet_show_menu (AppletInfo     *info,
-		  GtkWidget      *menu,
-		  gboolean        custom_position,
-		  GdkEventButton *event)
+applet_show_menu (AppletInfo *info,
+                  GtkWidget  *menu,
+                  GdkEvent   *event)
 {
 	PanelWidget *panel_widget;
+	PanelOrientation orientation;
+	GdkGravity widget_anchor;
+	GdkGravity menu_anchor;
 
 	g_return_if_fail (info != NULL);
 
@@ -588,21 +500,27 @@ applet_show_menu (AppletInfo     *info,
 		return;
 
 	panel_widget = panel_applet_get_panel_widget (info);
+	orientation = panel_widget_get_applet_orientation (panel_widget);
 
-	gtk_menu_set_screen (GTK_MENU (menu),
-			     gtk_window_get_screen (GTK_WINDOW (panel_widget->toplevel)));
+	if (orientation == PANEL_ORIENTATION_TOP) {
+		widget_anchor = GDK_GRAVITY_SOUTH_WEST;
+		menu_anchor = GDK_GRAVITY_NORTH_WEST;
+	} else if (orientation == PANEL_ORIENTATION_LEFT) {
+		widget_anchor = GDK_GRAVITY_NORTH_EAST;
+		menu_anchor = GDK_GRAVITY_NORTH_WEST;
+	} else if (orientation == PANEL_ORIENTATION_RIGHT) {
+		widget_anchor = GDK_GRAVITY_NORTH_WEST;
+		menu_anchor = GDK_GRAVITY_NORTH_EAST;
+	} else if (orientation == PANEL_ORIENTATION_BOTTOM) {
+		widget_anchor = GDK_GRAVITY_NORTH_WEST;
+		menu_anchor = GDK_GRAVITY_SOUTH_WEST;
+	} else {
+		g_assert_not_reached ();
+	}
 
-	if (!gtk_widget_get_realized (menu))
-		gtk_widget_show (menu);
-
-	gtk_menu_popup (GTK_MENU (menu),
-			NULL,
-			NULL,
-			custom_position ?
-				(GtkMenuPositionFunc) panel_applet_position_menu : NULL,
-			info->widget,
-			event->button,
-			event->time);
+	gtk_menu_popup_at_widget (GTK_MENU (menu), info->widget,
+	                          widget_anchor, menu_anchor,
+	                          event);
 }
 
 static gboolean
@@ -633,9 +551,9 @@ applet_button_press (GtkWidget      *widget,
 	modifiers = event->state & gtk_accelerator_get_default_mod_mask ();
 
 	if (modifiers == panel_bindings_get_mouse_button_modifier_keymask ())
-		applet_show_menu (info, panel_applet_get_edit_menu (info), FALSE, event);
+		applet_show_menu (info, panel_applet_get_edit_menu (info), (GdkEvent *) event);
 	else
-		applet_show_menu (info, panel_applet_get_menu (info), TRUE, event);
+		applet_show_menu (info, panel_applet_get_menu (info), (GdkEvent *) event);
 
 	return TRUE;
 }
@@ -664,9 +582,9 @@ applet_key_press (GtkWidget   *widget,
 	panel_util_key_event_is_popup (event, &is_popup, &is_edit_popup);
 
 	if (is_edit_popup)
-		applet_show_menu (info, panel_applet_get_edit_menu (info), FALSE, &eventbutton);
+		applet_show_menu (info, panel_applet_get_edit_menu (info), (GdkEvent *) &eventbutton);
 	else if (is_popup)
-		applet_show_menu (info, panel_applet_get_menu (info), TRUE, &eventbutton);
+		applet_show_menu (info, panel_applet_get_menu (info), (GdkEvent *) &eventbutton);
 
 	return (is_popup || is_edit_popup);
 }
@@ -821,65 +739,12 @@ panel_applet_get_id (AppletInfo *info)
 	return info->id;
 }
 
-const char *
-panel_applet_get_id_by_widget (GtkWidget *applet_widget)
-{
-	GSList *l;
-
-	if (!applet_widget)
-		return NULL;
-
-	for (l = registered_applets; l; l = l->next) {
-		AppletInfo *info = l->data;
-
-		if (info->widget == applet_widget)
-			return info->id;
-	}
-
-	return NULL;
-}
-
-AppletInfo *
-panel_applet_get_by_id (const char *id)
-{
-	GSList *l;
-
-	for (l = registered_applets; l; l = l->next) {
-		AppletInfo *info = l->data;
-
-		if (!strcmp (info->id, id))
-			return info;
-	}
-
-	return NULL;
-}
-
 GSList *
 panel_applet_list_applets (void)
 {
 	return registered_applets;
 }
 
-AppletInfo *
-panel_applet_get_by_type (PanelObjectType object_type, GdkScreen *screen)
-{
-	GSList *l;
-
-	for (l = registered_applets; l; l = l->next) {
-		AppletInfo *info = l->data;
-
-		if (info->type == object_type) {
-			if (screen) {
-				if (screen == gtk_widget_get_screen (info->widget))
-					return info;
-			} else
-				return info;
-		}
-	}
-
-	return NULL;
-}
-
 gboolean
 panel_applet_activate_main_menu (guint32 activate_time)
 {
@@ -980,14 +845,6 @@ panel_applet_register (GtkWidget       *applet,
 	return info;
 }
 
-GSettings *
-panel_applet_get_settings (AppletInfo *applet)
-{
-	g_return_val_if_fail (applet != NULL, NULL);
-
-	return applet->settings;
-}
-
 gboolean
 panel_applet_can_freely_move (AppletInfo *applet)
 {
