@@ -214,6 +214,13 @@ panel_addto_drag_begin_cb (GtkWidget      *widget,
 	g_object_unref (gicon);
 }
 
+static void
+free_drag_text (gpointer  data,
+                GClosure *closure)
+{
+	g_free (data);
+}
+
 static void
 panel_addto_setup_drag (GtkTreeView          *tree_view,
 			const GtkTargetEntry *target,
@@ -229,7 +236,7 @@ panel_addto_setup_drag (GtkTreeView          *tree_view,
 	g_signal_connect_data (G_OBJECT (tree_view), "drag_data_get",
 			       G_CALLBACK (panel_addto_drag_data_get_cb),
 			       g_strdup (text),
-			       (GClosureNotify) g_free,
+			       free_drag_text,
 			       0 /* connect_flags */);
 	g_signal_connect_after (G_OBJECT (tree_view), "drag-begin",
 	                        G_CALLBACK (panel_addto_drag_begin_cb),
@@ -1234,7 +1241,10 @@ panel_addto_present (GtkMenuItem *item,
 	PanelObjectPackType insert_pack_type;
 	GdkEvent *current_event;
 	GdkScreen *screen;
-	gint screen_height;
+	GdkDisplay *display;
+	GdkWindow *window;
+	GdkMonitor *monitor;
+	GdkRectangle workarea;
 	gint height;
 
 	toplevel = panel_widget->toplevel;
@@ -1247,8 +1257,11 @@ panel_addto_present (GtkMenuItem *item,
 				     panel_addto_dialog_quark);
 
 	screen = gtk_window_get_screen (GTK_WINDOW (toplevel));
-	screen_height = gdk_screen_get_height (screen);
-	height = MIN (MAX_ADDTOPANEL_HEIGHT, 3 * (screen_height / 4));
+	display = gdk_screen_get_display (screen);
+	window = gtk_widget_get_window (GTK_WIDGET (panel_widget));
+	monitor = gdk_display_get_monitor_at_window (display, window);
+	gdk_monitor_get_workarea (monitor, &workarea);
+	height = MIN (MAX_ADDTOPANEL_HEIGHT, 3 * (workarea.height / 4));
 
 	if (!dialog) {
 		dialog = panel_addto_dialog_new (panel_widget);
