@@ -576,6 +576,7 @@ panel_ditem_editor_make_ui (PanelDItemEditor *dialog)
 {
 	PanelDItemEditorPrivate *priv;
 	GtkWidget *dialog_vbox;
+	GtkWidget *hbox;
 
 	priv = dialog->priv;
 
@@ -584,11 +585,23 @@ panel_ditem_editor_make_ui (PanelDItemEditor *dialog)
 	dialog_vbox = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 	gtk_box_set_spacing (GTK_BOX (dialog_vbox), 2);
 
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
+	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
+	gtk_box_pack_start (GTK_BOX (dialog_vbox), hbox, TRUE, TRUE, 0);
+	gtk_widget_show (hbox);
+
+	/* Icon */
+	priv->icon_chooser = panel_icon_chooser_new (NULL);
+	panel_icon_chooser_set_fallback_icon_name (PANEL_ICON_CHOOSER (priv->icon_chooser),
+						   PANEL_ICON_LAUNCHER);
+	gtk_box_pack_start (GTK_BOX (hbox), priv->icon_chooser, FALSE, FALSE, 0);
+	gtk_widget_set_valign (priv->icon_chooser, GTK_ALIGN_START);
+	gtk_widget_show (priv->icon_chooser);
+
 	priv->grid = gtk_grid_new ();
-	gtk_container_set_border_width (GTK_CONTAINER (priv->grid), 5);
 	gtk_grid_set_row_spacing (GTK_GRID (priv->grid), 6);
 	gtk_grid_set_column_spacing (GTK_GRID (priv->grid), 12);
-	gtk_box_pack_start (GTK_BOX (dialog_vbox), priv->grid, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), priv->grid, TRUE, TRUE, 0);
 	gtk_widget_show (priv->grid);
 
 	/* Type */
@@ -605,13 +618,6 @@ panel_ditem_editor_make_ui (PanelDItemEditor *dialog)
 	gtk_label_set_mnemonic_widget (GTK_LABEL (priv->name_label),
 				       priv->name_entry);
 
-	/* Icon */
-	priv->icon_chooser = panel_icon_chooser_new (NULL);
-	panel_icon_chooser_set_fallback_icon_name (PANEL_ICON_CHOOSER (priv->icon_chooser),
-						   PANEL_ICON_LAUNCHER);
-	gtk_grid_attach (GTK_GRID (priv->grid), priv->icon_chooser, 0, 0, 1, 2);
-	gtk_widget_show (priv->icon_chooser);
-
 	/* Command */
 	priv->command_label = label_new_with_mnemonic ("");
 
@@ -662,7 +668,6 @@ panel_ditem_editor_setup_ui (PanelDItemEditor *dialog)
 	PanelDItemEditorPrivate *priv;
 	PanelDItemEditorType     type;
 	gboolean                 show_combo;
-	GList                   *focus_chain;
 
 	priv = dialog->priv;
 	type = panel_ditem_editor_get_item_type (dialog);
@@ -747,18 +752,6 @@ panel_ditem_editor_setup_ui (PanelDItemEditor *dialog)
 
 	type_combo_changed (dialog);
 
-	/* set a focus chain since GTK+ doesn't want to put the icon entry
-	 * as the first widget in the chain */
-	focus_chain = NULL;
-	focus_chain = g_list_prepend (focus_chain, priv->icon_chooser);
-	focus_chain = g_list_prepend (focus_chain, priv->type_combo);
-	focus_chain = g_list_prepend (focus_chain, priv->name_entry);
-	focus_chain = g_list_prepend (focus_chain, priv->command_hbox);
-	focus_chain = g_list_prepend (focus_chain, priv->comment_entry);
-	focus_chain = g_list_reverse (focus_chain);
-	gtk_container_set_focus_chain (GTK_CONTAINER (priv->grid), focus_chain);
-	g_list_free (focus_chain);
-
 	gtk_widget_grab_focus (priv->name_entry);
 }
 
@@ -871,6 +864,8 @@ panel_ditem_editor_command_changed (PanelDItemEditor *dialog)
 		panel_key_file_set_string (dialog->priv->key_file, "URL",
 					   exec_or_uri);
 		break;
+	case PANEL_DITEM_EDITOR_TYPE_DIRECTORY:
+	case PANEL_DITEM_EDITOR_TYPE_NULL:
 	default:
 		panel_key_file_remove_key (dialog->priv->key_file, "Exec");
 		panel_key_file_remove_key (dialog->priv->key_file, "URL");
@@ -932,6 +927,8 @@ command_browse_chooser_response (GtkFileChooser   *chooser,
 		case PANEL_DITEM_EDITOR_TYPE_LINK:
 			uri = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (chooser));
 			break;
+		case PANEL_DITEM_EDITOR_TYPE_NULL:
+		case PANEL_DITEM_EDITOR_TYPE_DIRECTORY:
 		default:
 			g_assert_not_reached ();
 		}
@@ -965,6 +962,8 @@ update_chooser_for_type (PanelDItemEditor *dialog)
 		title = _("Choose a file...");
 		local_only = FALSE;
 		break;
+	case PANEL_DITEM_EDITOR_TYPE_DIRECTORY:
+	case PANEL_DITEM_EDITOR_TYPE_NULL:
 	default:
 		g_assert_not_reached ();
 	}
@@ -1157,6 +1156,7 @@ type_combo_changed (PanelDItemEditor *dialog)
 						   "Type", "Directory");
 		}
 		return;
+	case PANEL_DITEM_EDITOR_TYPE_NULL:
 	default:
 		g_assert_not_reached ();
 	}
@@ -1332,6 +1332,8 @@ panel_ditem_editor_save (PanelDItemEditor *dialog,
 		case PANEL_DITEM_EDITOR_TYPE_LINK:
 			err = _("The location of the launcher is not set.");
 			break;
+		case PANEL_DITEM_EDITOR_TYPE_DIRECTORY:
+		case PANEL_DITEM_EDITOR_TYPE_NULL:
 		default:
 			g_assert_not_reached ();
 		}
@@ -1428,7 +1430,7 @@ response_cb (GtkDialog *dialog,
 static void
 panel_ditem_editor_revert (PanelDItemEditor *dialog)
 {
-	int       i;
+	gulong    i;
 	char     *string;
 	gboolean  boolean;
 	GKeyFile *key_file;
@@ -1504,7 +1506,7 @@ panel_ditem_editor_revert (PanelDItemEditor *dialog)
 static void
 panel_ditem_editor_set_revert (PanelDItemEditor *dialog)
 {
-	int       i;
+	gulong    i;
 	char     *string;
 	gboolean  boolean;
 	GKeyFile *key_file;
