@@ -46,12 +46,6 @@ typedef enum {
 	PANEL_ANIMATION_FAST   = 2
 } PanelAnimationSpeed;
 
-typedef enum {
-	PANEL_BACK_NONE  = 0,
-	PANEL_BACK_COLOR = 1,
-	PANEL_BACK_IMAGE = 2
-} PanelBackgroundType;
-
 typedef enum {
 	PANEL_BACKGROUND_IMAGE_STYLE_NONE    = 0,
 	PANEL_BACKGROUND_IMAGE_STYLE_STRETCH = 1,
