@@ -48,10 +48,9 @@ display_popup_window (GdkScreen *screen)
 	GtkWidget     *image;
 	GtkWidget     *frame;
 	GtkWidget     *label;
-	int            screen_width, screen_height;
-	GtkAllocation  allocation;
 
 	retval = gtk_window_new (GTK_WINDOW_POPUP);
+	gtk_window_set_position (GTK_WINDOW (retval), GTK_WIN_POS_CENTER);
 	atk_object_set_role (gtk_widget_get_accessible (retval), ATK_ROLE_ALERT);
 	gtk_window_set_screen (GTK_WINDOW (retval), screen);
 	gtk_window_stick (GTK_WINDOW (retval));
@@ -79,17 +78,6 @@ display_popup_window (GdkScreen *screen)
 	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 4);
 	gtk_widget_show (label);
 
-	gtk_widget_realize (retval);
-
-	screen_width  = gdk_screen_get_width  (screen);
-	screen_height = gdk_screen_get_height (screen);
-
-	gtk_widget_get_allocation (retval, &allocation);
-
-	gtk_window_move (GTK_WINDOW (retval),
-			 (screen_width  - allocation.width) / 2,
-			 (screen_height - allocation.height) / 2);
-
 	gtk_widget_show (GTK_WIDGET (retval));
 
 	return retval;
@@ -100,9 +88,7 @@ remove_popup (GtkWidget *popup)
 {
 	GdkWindow     *root;
 	GdkDisplay    *display;
-	GdkDevice     *pointer;
-	GdkDevice     *keyboard;
-	GdkDeviceManager *device_manager;
+	GdkSeat       *seat;
 
 	root = gdk_screen_get_root_window (
 			gtk_window_get_screen (GTK_WINDOW (popup)));
@@ -111,17 +97,15 @@ remove_popup (GtkWidget *popup)
 	gtk_widget_destroy (popup);
 
 	display = gdk_window_get_display (root);
-	device_manager = gdk_display_get_device_manager (display);
-	pointer = gdk_device_manager_get_client_pointer (device_manager);
-	keyboard = gdk_device_get_associated_device (pointer);
+	seat = gdk_display_get_default_seat (display);
 
-	gdk_device_ungrab (pointer, GDK_CURRENT_TIME);
-	gdk_device_ungrab (keyboard, GDK_CURRENT_TIME);
+	gdk_seat_ungrab (seat);
 }
 
 static gboolean
-wm_state_set (Display *display,
-	      Window   window)
+wm_state_set (GdkDisplay *display,
+              Display    *xdisplay,
+              Window      window)
 {
 	gulong  nitems;
 	gulong  bytes_after;
@@ -130,13 +114,13 @@ wm_state_set (Display *display,
 	int     ret_format;
 	int     result;
 
-	gdk_error_trap_push ();
-	result = XGetWindowProperty (display, window, wm_state_atom,
+	gdk_x11_display_error_trap_push (display);
+	result = XGetWindowProperty (xdisplay, window, wm_state_atom,
 				     0, G_MAXLONG, False, wm_state_atom,
 				     &ret_type, &ret_format, &nitems,
 				     &bytes_after, (gpointer) &prop);
 
-	if (gdk_error_trap_pop ())
+	if (gdk_x11_display_error_trap_pop (display))
 		return FALSE;
 
 	if (result != Success)
@@ -151,33 +135,35 @@ wm_state_set (Display *display,
 }
 
 static Window 
-find_managed_window (Display *display,
-		     Window   window)
+find_managed_window (GdkDisplay *display,
+                     Display    *xdisplay,
+                     Window      window)
 {
 	Window  root;
 	Window  parent;
 	Window *kids = NULL;
 	Window  retval;
 	guint   nkids;
-	int     i, result;
+	guint   i;
+	int     result;
 
-	if (wm_state_set (display, window))
+	if (wm_state_set (display, xdisplay, window))
 		return window;
 
-	gdk_error_trap_push ();
-	result = XQueryTree (display, window, &root, &parent, &kids, &nkids);
-	if (gdk_error_trap_pop () || !result)
+	gdk_x11_display_error_trap_push (display);
+	result = XQueryTree (xdisplay, window, &root, &parent, &kids, &nkids);
+	if (gdk_x11_display_error_trap_pop (display) || !result)
 		return None;
 
 	retval = None;
 
 	for (i = 0; i < nkids; i++) {
-		if (wm_state_set (display, kids [i])) {
+		if (wm_state_set (display, xdisplay, kids [i])) {
 			retval = kids [i];
 			break;
 		}
 
-		retval = find_managed_window (display, kids [i]);
+		retval = find_managed_window (display, xdisplay, kids [i]);
 		if (retval != None)
 			break;
 	}
@@ -247,23 +233,26 @@ kill_window_question (gpointer window)
 
 static void 
 handle_button_press_event (GtkWidget *popup,
-			   Display *display,
-			   Window subwindow)
+                           Display   *xdisplay,
+                           Window     subwindow)
 {
+	GdkDisplay *display;
 	Window window;
 
+	display = gtk_widget_get_display (popup);
+
 	remove_popup (popup);
 
 	if (subwindow == None)
 		return;
 
 	if (wm_state_atom == None)
-		wm_state_atom = XInternAtom (display, "WM_STATE", FALSE);
+		wm_state_atom = XInternAtom (xdisplay, "WM_STATE", FALSE);
 
-	window = find_managed_window (display, subwindow);
+	window = find_managed_window (display, xdisplay, subwindow);
 
 	if (window != None) {
-		if (!gdk_x11_window_lookup_for_display (gdk_x11_lookup_xdisplay (display), window))
+		if (!gdk_x11_window_lookup_for_display (gdk_x11_lookup_xdisplay (xdisplay), window))
 			kill_window_question ((gpointer) window);
 	}
 }
@@ -300,6 +289,8 @@ popup_filter (GdkXEvent *gdk_xevent,
 		case XI_ButtonPress:
 			handle_button_press_event (popup, xidev->display, xidev->child);
 			return GDK_FILTER_REMOVE;
+		default:
+			break;
 		}
 		break;
 	default:
@@ -309,6 +300,14 @@ popup_filter (GdkXEvent *gdk_xevent,
 	return GDK_FILTER_CONTINUE;
 }
 
+static void
+prepare_cb (GdkSeat   *seat,
+            GdkWindow *window,
+            gpointer   user_data)
+{
+	gdk_window_show_unraised (window);
+}
+
 void
 panel_force_quit (GdkScreen *screen,
 		  guint      time)
@@ -318,9 +317,7 @@ panel_force_quit (GdkScreen *screen,
 	GtkWidget     *popup;
 	GdkWindow     *root;
 	GdkDisplay    *display;
-	GdkDevice     *pointer;
-	GdkDevice     *keyboard;
-	GdkDeviceManager *device_manager;
+	GdkSeat       *seat;
 
 	popup = display_popup_window (screen);
 
@@ -332,29 +329,22 @@ panel_force_quit (GdkScreen *screen,
 	                                    GDK_CROSS);
 
 	display = gdk_window_get_display (root);
-	device_manager = gdk_display_get_device_manager (display);
-	pointer = gdk_device_manager_get_client_pointer (device_manager);
-	keyboard = gdk_device_get_associated_device (pointer);
+	seat = gdk_display_get_default_seat (display);
 
-	status = gdk_device_grab (pointer, root,
-				  GDK_OWNERSHIP_NONE, FALSE,
-				  GDK_BUTTON_PRESS_MASK,
-				  cross, time);
+	status = gdk_seat_grab (seat,
+	                        root,
+	                        GDK_SEAT_CAPABILITY_POINTER |
+	                        GDK_SEAT_CAPABILITY_KEYBOARD,
+	                        TRUE,
+	                        cross,
+	                        NULL,
+	                        prepare_cb,
+	                        NULL);
 
 	g_object_unref (cross);
 
 	if (status != GDK_GRAB_SUCCESS) {
-		g_warning ("Pointer grab failed\n");
-		remove_popup (popup);
-		return;
-	}
-
-	status = gdk_device_grab (keyboard, root,
-				  GDK_OWNERSHIP_NONE, FALSE,
-				  GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK,
-				  NULL, time);
-	if (status != GDK_GRAB_SUCCESS) {
-		g_warning ("Keyboard grab failed\n");
+		g_warning ("Seat grab failed.");
 		remove_popup (popup);
 		return;
 	}
