@@ -48,14 +48,14 @@ typedef struct _CalendarClientSource CalendarClientSource;
 
 struct _CalendarClientQuery
 {
-  ECalView   *view;
-  GHashTable *events;
+  ECalClientView *view;
+  GHashTable     *events;
 };
 
 struct _CalendarClientSource
 {
   CalendarClient      *client;
-  ECal                *source;
+  ECalClient          *source;
 
   CalendarClientQuery  completed_query;
   CalendarClientQuery  in_progress_query;
@@ -73,7 +73,7 @@ struct _CalendarClientPrivate
   GSList              *appointment_sources;
   GSList              *task_sources;
 
-  icaltimezone        *zone;
+  ICalTimezone        *zone;
 
   guint                zone_listener;
   GSettings           *calendar_settings;
@@ -199,21 +199,21 @@ calendar_client_config_get_timezone (GSettings *calendar_settings)
   return g_settings_get_string (calendar_settings, "timezone");
 }
 
-static icaltimezone *
+static ICalTimezone *
 calendar_client_config_get_icaltimezone (CalendarClient *client)
 {
   gchar        *location = NULL;
-  icaltimezone *zone = NULL;
+  ICalTimezone *zone = NULL;
 
   if (client->priv->calendar_settings != NULL)
     location = calendar_client_config_get_timezone (client->priv->calendar_settings);
 
   if (!location)
-    return icaltimezone_get_utc_timezone ();
+    return i_cal_timezone_get_utc_timezone ();
 
-  zone = icaltimezone_get_builtin_timezone (location);
+  zone = i_cal_timezone_get_builtin_timezone (location);
   g_free (location);
-	
+
   return zone;
 }
 
@@ -227,9 +227,9 @@ calendar_client_set_timezone (CalendarClient *client)
   list = calendar_sources_get_appointment_clients (client->priv->calendar_sources);
   for (link = list; link != NULL; link = g_list_next (link))
     {
-      ECal *cal = E_CAL (link->data);
+      ECalClient *cal = E_CAL_CLIENT (link->data);
 
-      e_cal_set_default_timezone (cal, client->priv->zone, NULL);
+      e_cal_client_set_default_timezone (cal, client->priv->zone);
     }
   g_list_free (list);
 }
@@ -242,46 +242,6 @@ calendar_client_timezone_changed_cb (GSettings      *calendar_settings,
   calendar_client_set_timezone (client);
 }
 
-static void
-cal_opened_cb (ECal                 *ecal,
-               ECalendarStatus       status,
-               CalendarClientSource *cl_source)
-{
-  ECalSourceType  s_type;
-  CalendarClient *client = cl_source->client;
-
-  s_type = e_cal_get_source_type (ecal);
-
-  if (status == E_CALENDAR_STATUS_BUSY &&
-      e_cal_get_load_state (ecal) == E_CAL_LOAD_NOT_LOADED)
-    {
-      e_cal_open_async (ecal, FALSE);
-      return;
-    }
-  
-  g_signal_handlers_disconnect_by_func (ecal, cal_opened_cb, cl_source);
-
-  if (status != E_CALENDAR_STATUS_OK)
-    {
-      if (s_type == E_CAL_SOURCE_TYPE_EVENT)
-        client->priv->appointment_sources = g_slist_remove (client->priv->appointment_sources,
-                                                            cl_source);
-      else
-        client->priv->task_sources = g_slist_remove (client->priv->task_sources,
-                                                     cl_source);
-
-      calendar_client_source_finalize (cl_source);
-      g_free (cl_source);
-
-      return;
-    }
-
-  if (s_type == E_CAL_SOURCE_TYPE_EVENT)
-    calendar_client_update_appointments (client);
-  else
-    calendar_client_update_tasks (client);
-}
-
 static void
 load_calendars (CalendarClient    *client,
                 CalendarEventType  type) 
@@ -303,17 +263,10 @@ load_calendars (CalendarClient    *client,
 
   for (l = clients; l != NULL; l = l->next)
     {
-      ECal *ecal;	
-      CalendarClientSource *cl_source = l->data;
-
-      ecal = cl_source->source;
-
-      if (e_cal_get_load_state (ecal) == E_CAL_LOAD_LOADED)
-        continue;
-
-      g_signal_connect (G_OBJECT (ecal), "cal_opened",
-                        G_CALLBACK (cal_opened_cb), cl_source);
-      e_cal_open_async (ecal, TRUE);
+      if (type == CALENDAR_EVENT_APPOINTMENT)
+        calendar_client_update_appointments (client);
+      else if (type == CALENDAR_EVENT_TASK)
+        calendar_client_update_tasks (client);
     }
 }
 
@@ -505,113 +458,153 @@ make_isodate_for_day_begin (int day,
 }
 
 static time_t
-get_time_from_property (icalcomponent         *ical,
-			icalproperty_kind      prop_kind,
-			struct icaltimetype (* get_prop_func) (const icalproperty *prop),
-                        icaltimezone          *default_zone)
+get_time_from_property (ICalComponent    *icomp,
+                        ICalPropertyKind  prop_kind,
+                        ICalTime         * (* get_prop_func) (ICalProperty *prop),
+                        ICalTimezone     *default_zone)
 {
-  icalproperty        *prop;
-  struct icaltimetype  ical_time;
-  icalparameter       *param;
-  icaltimezone        *timezone = NULL;
-  
-  prop = icalcomponent_get_first_property (ical, prop_kind);
+  ICalProperty *prop;
+  ICalTime *ical_time;
+  ICalParameter *param;
+  ICalTimezone *timezone;
+  time_t retval;
+
+  prop = i_cal_component_get_first_property (icomp, prop_kind);
   if (!prop)
     return 0;
 
+  param = i_cal_property_get_first_parameter (prop, I_CAL_TZID_PARAMETER);
   ical_time = get_prop_func (prop);
+  g_object_unref (prop);
 
-  param = icalproperty_get_first_parameter (prop, ICAL_TZID_PARAMETER);
   if (param)
-    timezone = icaltimezone_get_builtin_timezone_from_tzid (icalparameter_get_tzid (param));
-  else if (icaltime_is_utc (ical_time))
-    timezone = icaltimezone_get_utc_timezone ();
-  else 
-    timezone = default_zone;
+    {
+      const char *tzid;
 
-  return icaltime_as_timet_with_zone (ical_time, timezone);
+      tzid = i_cal_parameter_get_tzid (param);
+      timezone = i_cal_timezone_get_builtin_timezone_from_tzid (tzid);
+      g_object_unref (param);
+    }
+  else if (i_cal_time_is_utc (ical_time))
+    {
+      timezone = i_cal_timezone_get_utc_timezone ();
+    }
+  else
+    {
+      timezone = default_zone;
+    }
+
+  retval = i_cal_time_as_timet_with_zone (ical_time, timezone);
+  g_object_unref (ical_time);
+
+  return retval;
 }
 
 static char *
-get_ical_uid (icalcomponent *ical)
+get_component_uid (ICalComponent *component)
 {
-  return g_strdup (icalcomponent_get_uid (ical));
+  return g_strdup (i_cal_component_get_uid (component));
 }
 
 static char *
-get_ical_rid (icalcomponent *ical)
+get_component_rid (ICalComponent *component)
 {
-  icalproperty        *prop;
-  struct icaltimetype  ical_time;
-  
-  prop = icalcomponent_get_first_property (ical, ICAL_RECURRENCEID_PROPERTY);
+  ICalProperty *prop;
+  ICalTime *time;
+  char *rid;
+
+  prop = i_cal_component_get_first_property (component, ICAL_RECURRENCEID_PROPERTY);
   if (!prop)
     return NULL;
 
-  ical_time = icalproperty_get_recurrenceid (prop);
+  time = i_cal_property_get_recurrenceid (prop);
+  g_object_unref (prop);
 
-  return icaltime_is_valid_time (ical_time) && !icaltime_is_null_time (ical_time) ? 
-    g_strdup (icaltime_as_ical_string (ical_time)) : NULL;
+  if (!i_cal_time_is_valid_time (time) || i_cal_time_is_null_time (time))
+    {
+      g_object_unref (time);
+      return NULL;
+    }
+
+  rid = g_strdup (i_cal_time_as_ical_string (time));
+  g_object_unref (time);
+
+  return rid;
 }
 
 static char *
-get_ical_summary (icalcomponent *ical)
+get_component_summary (ICalComponent *component)
 {
-  icalproperty *prop;
+  ICalProperty *prop;
+  char *summary;
 
-  prop = icalcomponent_get_first_property (ical, ICAL_SUMMARY_PROPERTY);
+  prop = i_cal_component_get_first_property (component, I_CAL_SUMMARY_PROPERTY);
   if (!prop)
     return NULL;
 
-  return g_strdup (icalproperty_get_summary (prop));
+  summary = g_strdup (i_cal_property_get_summary (prop));
+  g_object_unref (prop);
+
+  return summary;
 }
 
 static char *
-get_ical_description (icalcomponent *ical)
+get_component_description (ICalComponent *component)
 {
-  icalproperty *prop;
+  ICalProperty *prop;
+  char *description;
 
-  prop = icalcomponent_get_first_property (ical, ICAL_DESCRIPTION_PROPERTY);
+  prop = i_cal_component_get_first_property (component, I_CAL_DESCRIPTION_PROPERTY);
   if (!prop)
     return NULL;
 
-  return g_strdup (icalproperty_get_description (prop));
+  description = g_strdup (i_cal_property_get_description (prop));
+  g_object_unref (prop);
+
+  return description;
 }
 
 static inline time_t
-get_ical_start_time (icalcomponent *ical,
-                     icaltimezone  *default_zone)
+get_component_start_time (ICalComponent *component,
+                          ICalTimezone  *default_zone)
 {
-  return get_time_from_property (ical,
-				 ICAL_DTSTART_PROPERTY,
-				 icalproperty_get_dtstart,
+  return get_time_from_property (component,
+                                 I_CAL_DTSTART_PROPERTY,
+                                 i_cal_property_get_dtstart,
                                  default_zone);
 }
 
 static inline time_t
-get_ical_end_time (icalcomponent *ical,
-                   icaltimezone  *default_zone)
+get_component_end_time (ICalComponent *component,
+                        ICalTimezone  *default_zone)
 {
-  return get_time_from_property (ical,
-				 ICAL_DTEND_PROPERTY,
-				 icalproperty_get_dtend,
+  return get_time_from_property (component,
+                                 I_CAL_DTEND_PROPERTY,
+                                 i_cal_property_get_dtend,
                                  default_zone);
 }
 
 static gboolean
-get_ical_is_all_day (icalcomponent *ical,
-                     time_t         start_time,
-                     icaltimezone  *default_zone)
+get_component_is_all_day (ICalComponent *component,
+                          time_t         start_time,
+                          ICalTimezone  *default_zone)
 {
-  icalproperty            *prop;
-  struct tm               *start_tm;
-  time_t                   end_time;
-  struct icaldurationtype  duration;
-  struct icaltimetype      start_icaltime;
+  ICalTime *dtstart;
+  struct tm *start_tm;
+  time_t end_time;
+  ICalProperty *prop;
+  ICalDuration *duration;
+  gboolean is_all_day;
 
-  start_icaltime = icalcomponent_get_dtstart (ical);
-  if (start_icaltime.is_date)
-    return TRUE;
+  dtstart = i_cal_component_get_dtstart (component);
+
+  if (dtstart && i_cal_time_is_date (dtstart))
+    {
+      g_object_unref (dtstart);
+      return TRUE;
+    }
+
+  g_object_unref (dtstart);
 
   start_tm = gmtime (&start_time);
   if (start_tm->tm_sec  != 0 ||
@@ -619,97 +612,110 @@ get_ical_is_all_day (icalcomponent *ical,
       start_tm->tm_hour != 0)
     return FALSE;
 
-  if ((end_time = get_ical_end_time (ical, default_zone)))
+  if ((end_time = get_component_end_time (component, default_zone)))
     return (end_time - start_time) % 86400 == 0;
 
-  prop = icalcomponent_get_first_property (ical, ICAL_DURATION_PROPERTY);
+  prop = i_cal_component_get_first_property (component, I_CAL_DURATION_PROPERTY);
   if (!prop)
     return FALSE;
 
-  duration = icalproperty_get_duration (prop);
+  duration = i_cal_property_get_duration (prop);
+  g_object_unref (prop);
 
-  return icaldurationtype_as_int (duration) % 86400 == 0;
+  is_all_day = i_cal_duration_as_int (duration) % 86400 == 0;
+  g_object_unref (duration);
+
+  return is_all_day;
 }
 
 static inline time_t
-get_ical_due_time (icalcomponent *ical,
-                   icaltimezone  *default_zone)
+get_component_due_time (ICalComponent *component,
+                        ICalTimezone  *default_zone)
 {
-  return get_time_from_property (ical,
-				 ICAL_DUE_PROPERTY,
-				 icalproperty_get_due,
+  return get_time_from_property (component,
+                                 I_CAL_DUE_PROPERTY,
+                                 i_cal_property_get_due,
                                  default_zone);
 }
 
 static guint
-get_ical_percent_complete (icalcomponent *ical)
+get_component_percent_complete (ICalComponent *component)
 {
-  icalproperty *prop;
-  icalproperty_status status;
-  int           percent_complete;
+  ICalPropertyStatus status;
+  ICalProperty *prop;
+  int percent_complete;
 
-  status = icalcomponent_get_status (ical);
-  if (status == ICAL_STATUS_COMPLETED)
+  status = i_cal_component_get_status (component);
+  if (status == I_CAL_STATUS_COMPLETED)
     return 100;
 
-  prop = icalcomponent_get_first_property (ical, ICAL_COMPLETED_PROPERTY);
+  prop = i_cal_component_get_first_property (component, I_CAL_COMPLETED_PROPERTY);
+
   if (prop)
-    return 100;
+    {
+      g_object_unref (prop);
+      return 100;
+    }
 
-  prop = icalcomponent_get_first_property (ical, ICAL_PERCENTCOMPLETE_PROPERTY);
+  prop = i_cal_component_get_first_property (component, I_CAL_PERCENTCOMPLETE_PROPERTY);
   if (!prop)
     return 0;
 
-  percent_complete = icalproperty_get_percentcomplete (prop);
+  percent_complete = i_cal_property_get_percentcomplete (prop);
+  g_object_unref (prop);
 
   return CLAMP (percent_complete, 0, 100);
 }
 
 static inline time_t
-get_ical_completed_time (icalcomponent *ical,
-                         icaltimezone  *default_zone)
+get_component_completed_time (ICalComponent *component,
+                              ICalTimezone  *default_zone)
 {
-  return get_time_from_property (ical,
-				 ICAL_COMPLETED_PROPERTY,
-				 icalproperty_get_completed,
+  return get_time_from_property (component,
+                                 I_CAL_COMPLETED_PROPERTY,
+                                 i_cal_property_get_completed,
                                  default_zone);
 }
 
 static int
-get_ical_priority (icalcomponent *ical)
+get_component_priority (ICalComponent *component)
 {
-  icalproperty *prop;
+  ICalProperty *prop;
+  int priority;
 
-  prop = icalcomponent_get_first_property (ical, ICAL_PRIORITY_PROPERTY);
+  prop = i_cal_component_get_first_property (component, I_CAL_PRIORITY_PROPERTY);
   if (!prop)
     return -1;
 
-  return icalproperty_get_priority (prop);
+  priority = i_cal_property_get_priority (prop);
+  g_object_unref (prop);
+
+  return priority;
 }
 
 static char *
-get_source_color (ECal *esource)
+get_source_color (ECalClient *esource)
 {
   ESource *source;
-  ECalSourceType source_type;
+  ECalClientSourceType source_type;
   ESourceSelectable *extension;
   const gchar *extension_name;
 
-  g_return_val_if_fail (E_IS_CAL (esource), NULL);
+  g_return_val_if_fail (E_IS_CAL_CLIENT (esource), NULL);
 
-  source = e_cal_get_source (esource);
-  source_type = e_cal_get_source_type (esource);
+  source = e_client_get_source (E_CLIENT (esource));
+  source_type = e_cal_client_get_source_type (esource);
 
   switch (source_type)
     {
-      case E_CAL_SOURCE_TYPE_EVENT:
+      case E_CAL_CLIENT_SOURCE_TYPE_EVENTS:
         extension_name = E_SOURCE_EXTENSION_CALENDAR;
         break;
-      case E_CAL_SOURCE_TYPE_TODO:
+      case E_CAL_CLIENT_SOURCE_TYPE_TASKS:
         extension_name = E_SOURCE_EXTENSION_TASK_LIST;
         break;
-      case E_CAL_SOURCE_TYPE_JOURNAL:
-      case E_CAL_SOURCE_TYPE_LAST:
+      case E_CAL_CLIENT_SOURCE_TYPE_MEMOS:
+      case E_CAL_CLIENT_SOURCE_TYPE_LAST:
       default:
         g_return_val_if_reached (NULL);
     }
@@ -720,28 +726,28 @@ get_source_color (ECal *esource)
 }
 
 static gchar *
-get_source_backend_name (ECal *esource)
+get_source_backend_name (ECalClient *esource)
 {
   ESource *source;
-  ECalSourceType source_type;
+  ECalClientSourceType source_type;
   ESourceBackend *extension;
   const gchar *extension_name;
 
-  g_return_val_if_fail (E_IS_CAL (esource), NULL);
+  g_return_val_if_fail (E_IS_CAL_CLIENT (esource), NULL);
 
-  source = e_cal_get_source (esource);
-  source_type = e_cal_get_source_type (esource);
+  source = e_client_get_source (E_CLIENT (esource));
+  source_type = e_cal_client_get_source_type (esource);
 
   switch (source_type)
     {
-      case E_CAL_SOURCE_TYPE_EVENT:
+      case E_CAL_CLIENT_SOURCE_TYPE_EVENTS:
         extension_name = E_SOURCE_EXTENSION_CALENDAR;
         break;
-      case E_CAL_SOURCE_TYPE_TODO:
+      case E_CAL_CLIENT_SOURCE_TYPE_TASKS:
         extension_name = E_SOURCE_EXTENSION_TASK_LIST;
         break;
-      case E_CAL_SOURCE_TYPE_JOURNAL:
-      case E_CAL_SOURCE_TYPE_LAST:
+      case E_CAL_CLIENT_SOURCE_TYPE_MEMOS:
+      case E_CAL_CLIENT_SOURCE_TYPE_LAST:
       default:
         g_return_val_if_reached (NULL);
     }
@@ -847,50 +853,60 @@ calendar_appointment_finalize (CalendarAppointment *appointment)
 
 static void
 calendar_appointment_init (CalendarAppointment  *appointment,
-			   icalcomponent        *ical,
+                           ICalComponent        *component,
                            CalendarClientSource *source,
-                           icaltimezone         *default_zone)
+                           ICalTimezone         *default_zone)
 {
-  appointment->uid          = get_ical_uid (ical);
-  appointment->rid          = get_ical_rid (ical);
+  appointment->uid = get_component_uid (component);
+  appointment->rid = get_component_rid (component);
   appointment->backend_name = get_source_backend_name (source->source);
-  appointment->summary      = get_ical_summary (ical);
-  appointment->description  = get_ical_description (ical);
+  appointment->summary = get_component_summary (component);
+  appointment->description = get_component_description (component);
   appointment->color_string = get_source_color (source->source);
-  appointment->start_time   = get_ical_start_time (ical, default_zone);
-  appointment->end_time     = get_ical_end_time (ical, default_zone);
-  appointment->is_all_day   = get_ical_is_all_day (ical,
-                                                   appointment->start_time,
-                                                   default_zone);
+  appointment->start_time = get_component_start_time (component, default_zone);
+  appointment->end_time = get_component_end_time (component, default_zone);
+  appointment->is_all_day = get_component_is_all_day (component,
+                                                      appointment->start_time,
+                                                      default_zone);
 }
 
-static icaltimezone *
-resolve_timezone_id (const char *tzid,
-		     ECal       *source)
+static ICalTimezone *
+resolve_timezone_id (const char    *tzid,
+                     gpointer       user_data,
+                     GCancellable  *cancellable,
+                     GError       **error)
 {
-  icaltimezone *retval;
+  ECalClient *client;
+  ICalTimezone *retval;
+
+  client = E_CAL_CLIENT (user_data);
+  retval = i_cal_timezone_get_builtin_timezone_from_tzid (tzid);
 
-  retval = icaltimezone_get_builtin_timezone_from_tzid (tzid);
   if (!retval)
-    {
-      e_cal_get_timezone (source, tzid, &retval, NULL);
-    }
+    e_cal_client_get_timezone_sync (client, tzid, &retval, NULL, NULL);
 
   return retval;
 }
 
 static gboolean
-calendar_appointment_collect_occurrence (ECalComponent  *component,
-					 time_t          occurrence_start,
-					 time_t          occurrence_end,
-					 gpointer        data)
+calendar_appointment_collect_occurrence (ICalComponent  *component,
+                                         ICalTime       *occurrence_start,
+                                         ICalTime       *occurrence_end,
+                                         gpointer        user_data,
+                                         GCancellable   *cancellable,
+                                         GError        **error)
 {
+  time_t start;
+  time_t end;
   CalendarOccurrence *occurrence;
-  GSList **collect_loc = data;
+  GSList **collect_loc = user_data;
 
-  occurrence             = g_new0 (CalendarOccurrence, 1);
-  occurrence->start_time = occurrence_start;
-  occurrence->end_time   = occurrence_end;
+  start = i_cal_time_as_timet (occurrence_start);
+  end = i_cal_time_as_timet (occurrence_end);
+
+  occurrence = g_new0 (CalendarOccurrence, 1);
+  occurrence->start_time = start;
+  occurrence->end_time = end;
 
   *collect_loc = g_slist_prepend (*collect_loc, occurrence);
 
@@ -899,30 +915,33 @@ calendar_appointment_collect_occurrence (ECalComponent  *component,
 
 static void
 calendar_appointment_generate_ocurrences (CalendarAppointment *appointment,
-					  icalcomponent       *ical,
-					  ECal                *source,
-					  time_t               start,
-					  time_t               end,
-                                          icaltimezone        *default_zone)
+                                          ICalComponent       *component,
+                                          ECalClient          *source,
+                                          time_t               start,
+                                          time_t               end,
+                                          ICalTimezone        *default_zone)
 {
-  ECalComponent *ecal;
+  ICalTime *start_time;
+  ICalTime *end_time;
 
   g_assert (appointment->occurrences == NULL);
 
-  ecal = e_cal_component_new ();
-  e_cal_component_set_icalcomponent (ecal,
-				     icalcomponent_new_clone (ical));
+  start_time = i_cal_time_new_from_timet_with_zone (start, FALSE, NULL);
+  end_time = i_cal_time_new_from_timet_with_zone (end, FALSE, NULL);
 
-  e_cal_recur_generate_instances (ecal,
-				  start,
-				  end,
-				  calendar_appointment_collect_occurrence,
-				  &appointment->occurrences,
-				  (ECalRecurResolveTimezoneFn) resolve_timezone_id,
-				  source,
-				  default_zone);
+  e_cal_recur_generate_instances_sync (component,
+                                       start_time,
+                                       end_time,
+                                       calendar_appointment_collect_occurrence,
+                                       &appointment->occurrences,
+                                       resolve_timezone_id,
+                                       source,
+                                       default_zone,
+                                       NULL,
+                                       NULL);
 
-  g_object_unref (ecal);
+  g_object_unref (start_time);
+ g_object_unref (end_time);
 
   appointment->occurrences = g_slist_reverse (appointment->occurrences);
 }
@@ -981,19 +1000,19 @@ calendar_task_finalize (CalendarTask *task)
 
 static void
 calendar_task_init (CalendarTask         *task,
-		    icalcomponent        *ical,
+                    ICalComponent        *component,
                     CalendarClientSource *source,
-                    icaltimezone         *default_zone)
+                    ICalTimezone         *default_zone)
 {
-  task->uid              = get_ical_uid (ical);
-  task->summary          = get_ical_summary (ical);
-  task->description      = get_ical_description (ical);
-  task->color_string     = get_source_color (source->source);
-  task->start_time       = get_ical_start_time (ical, default_zone);
-  task->due_time         = get_ical_due_time (ical, default_zone);
-  task->percent_complete = get_ical_percent_complete (ical);
-  task->completed_time   = get_ical_completed_time (ical, default_zone);
-  task->priority         = get_ical_priority (ical);
+  task->uid = get_component_uid (component);
+  task->summary = get_component_summary (component);
+  task->description = get_component_description (component);
+  task->color_string = get_source_color (source->source);
+  task->start_time = get_component_start_time (component, default_zone);
+  task->due_time = get_component_due_time (component, default_zone);
+  task->percent_complete = get_component_percent_complete (component);
+  task->completed_time = get_component_completed_time (component, default_zone);
+  task->priority = get_component_priority (component);
 }
 
 void
@@ -1017,31 +1036,31 @@ calendar_event_free (CalendarEvent *event)
 }
 
 static CalendarEvent *
-calendar_event_new (icalcomponent        *ical,
+calendar_event_new (ICalComponent        *component,
                     CalendarClientSource *source,
-                    icaltimezone         *default_zone)
+                    ICalTimezone         *default_zone)
 {
   CalendarEvent *event;
-  icalcomponent_kind component;
+  ICalComponentKind component_kind;
 
   event = g_new0 (CalendarEvent, 1);
-  component = icalcomponent_isa (ical);
+  component_kind = i_cal_component_isa (component);
 
-  if (component == ICAL_VEVENT_COMPONENT)
+  if (component_kind == I_CAL_VEVENT_COMPONENT)
     {
       event->type = CALENDAR_EVENT_APPOINTMENT;
       calendar_appointment_init (CALENDAR_APPOINTMENT (event),
-                                 ical, source, default_zone);
+                                 component, source, default_zone);
     }
-  else if (component == ICAL_VTODO_COMPONENT)
+  else if (component_kind == I_CAL_VTODO_COMPONENT)
     {
       event->type = CALENDAR_EVENT_TASK;
       calendar_task_init (CALENDAR_TASK (event),
-                          ical, source, default_zone);
+                          component, source, default_zone);
     }
   else
     {
-      g_warning ("Unknown calendar component type: %d\n", component);
+      g_warning ("Unknown calendar component type: %d\n", component_kind);
       g_free (event);
 
       return NULL;
@@ -1134,20 +1153,20 @@ calendar_event_equal (CalendarEvent *a,
 
 static void
 calendar_event_generate_ocurrences (CalendarEvent *event,
-				    icalcomponent *ical,
-				    ECal          *source,
-				    time_t         start,
-				    time_t         end,
-                                    icaltimezone  *default_zone)
+                                    ICalComponent *component,
+                                    ECalClient    *source,
+                                    time_t         start,
+                                    time_t         end,
+                                    ICalTimezone  *default_zone)
 {
   if (event->type != CALENDAR_EVENT_APPOINTMENT)
     return;
 
   calendar_appointment_generate_ocurrences (CALENDAR_APPOINTMENT (event),
-					    ical,
-					    source,
-					    start,
-					    end,
+                                            component,
+                                            source,
+                                            start,
+                                            end,
                                             default_zone);
 }
 
@@ -1241,8 +1260,8 @@ calendar_event_debug_dump (CalendarEvent *event)
 
 static inline CalendarClientQuery *
 goddamn_this_is_crack (CalendarClientSource *source,
-		       ECalView             *view,
-		       gboolean             *emit_signal)
+                       ECalClientView       *view,
+                       gboolean             *emit_signal)
 {
   g_assert (view != NULL);
 
@@ -1266,19 +1285,18 @@ goddamn_this_is_crack (CalendarClientSource *source,
 
 static void
 calendar_client_handle_query_completed (CalendarClientSource *source,
-					ECalendarStatus       status,
-					ECalView             *view)
+                                        GError               *error,
+                                        ECalClientView       *view)
 {
   CalendarClientQuery *query;
 
   query = goddamn_this_is_crack (source, view, NULL);
   
-  dprintf ("Query %p completed: %s\n", query, e_cal_get_error_message (status));
+  dprintf ("Query %p completed", query);
 
-  if (status != E_CALENDAR_STATUS_OK)
+  if (error != NULL)
     {
-      g_warning ("Calendar query failed: %s\n",
-		 e_cal_get_error_message (status));
+      g_warning ("Calendar query failed: %s", error->message);
       calendar_client_stop_query (source->client, source, query);
       return;
     }
@@ -1300,8 +1318,8 @@ calendar_client_handle_query_completed (CalendarClientSource *source,
 
 static void
 calendar_client_handle_query_result (CalendarClientSource *source,
-				     GList                *objects,
-				     ECalView             *view)
+                                     GList                *objects,
+                                     ECalClientView       *view)
 {
   CalendarClientQuery *query;
   CalendarClient      *client;
@@ -1331,18 +1349,18 @@ calendar_client_handle_query_result (CalendarClientSource *source,
     {
       CalendarEvent *event;
       CalendarEvent *old_event;
-      icalcomponent *ical = l->data;
+      ICalComponent *component = l->data;
       char          *uid;
       
-      event = calendar_event_new (ical, source, client->priv->zone);
+      event = calendar_event_new (component, source, client->priv->zone);
       if (!event)
 	      continue;
 
       calendar_event_generate_ocurrences (event,
-					  ical,
-					  source->source,
-					  month_begin,
-					  month_end,
+                                          component,
+                                          source->source,
+                                          month_begin,
+                                          month_end,
                                           client->priv->zone);
 
       uid = calendar_event_get_uid (event);
@@ -1396,8 +1414,8 @@ check_object_remove (gpointer key,
 
 static void
 calendar_client_handle_objects_removed (CalendarClientSource *source,
-					GList                *ids,
-					ECalView             *view)
+                                        GList                *ids,
+                                        ECalClientView       *view)
 {
   CalendarClientQuery *query;
   gboolean             emit_signal;
@@ -1409,30 +1427,38 @@ calendar_client_handle_objects_removed (CalendarClientSource *source,
   events_changed = FALSE;
   for (l = ids; l; l = l->next)
     {
-      CalendarEvent   *event;
-      ECalComponentId *id = l->data;
-      char            *uid = g_strdup_printf ("%s%s", id->uid, id->rid ? id->rid : "");
+      CalendarEvent *event;
+      ECalComponentId *id;
+      const char *uid;
+      const char *rid;
+      char  *key;
 
-      if (!id->rid || !(*id->rid))
-	{
-	  guint size = g_hash_table_size (query->events);
+      id = l->data;
+      uid = e_cal_component_id_get_uid (id);
+      rid = e_cal_component_id_get_rid (id);
+      key = g_strdup_printf ("%s%s", uid, rid ? rid : "");
 
-	  g_hash_table_foreach_remove (query->events, check_object_remove, id->uid);
+      if (!rid || !*rid)
+        {
+          guint size = g_hash_table_size (query->events);
 
-		if (size != g_hash_table_size (query->events))
-			events_changed = TRUE;		
-	}
-      else if ((event = g_hash_table_lookup (query->events, uid)))
-	{
-	  dprintf ("Event removed: ");
+          g_hash_table_foreach_remove (query->events, check_object_remove, (gpointer) uid);
 
-	  calendar_event_debug_dump (event);
+          if (size != g_hash_table_size (query->events))
+            events_changed = TRUE;
+        }
+      else if ((event = g_hash_table_lookup (query->events, key)))
+        {
+          dprintf ("Event removed: ");
 
-	  g_assert (g_hash_table_remove (query->events, uid));
+          calendar_event_debug_dump (event);
 
-	  events_changed = TRUE;
-	}
-      g_free (uid);
+          g_assert (g_hash_table_remove (query->events, key));
+
+          events_changed = TRUE;
+        }
+
+      g_free (key);
     }
 
   if (emit_signal && events_changed)
@@ -1485,13 +1511,14 @@ calendar_client_start_query (CalendarClient       *client,
 			     CalendarClientSource *source,
 			     const char           *query)
 {
-  ECalView *view = NULL;
-  GError   *error = NULL;
+  ECalClientView *view = NULL;
+  GError *error = NULL;
 
-  if (!e_cal_get_query (source->source, query, &view, &error))
+  if (!e_cal_client_get_view_sync (source->source, query, &view, NULL, &error))
     {
-      g_warning ("Error preparing the query: '%s': %s\n",
-		 query, error->message);
+      g_warning ("Error preparing the query: '%s': %s",
+                 query, error->message);
+
       g_error_free (error);
       return;
     }
@@ -1520,11 +1547,11 @@ calendar_client_start_query (CalendarClient       *client,
   g_signal_connect_swapped (view, "objects-removed",
 			    G_CALLBACK (calendar_client_handle_objects_removed),
 			    source);
-  g_signal_connect_swapped (view, "view-done",
+  g_signal_connect_swapped (view, "complete",
 			    G_CALLBACK (calendar_client_handle_query_completed),
 			    source);
 
-  e_cal_view_start (view);
+  e_cal_client_view_start (view, NULL);
 }
 
 static void
@@ -1553,9 +1580,6 @@ calendar_client_update_appointments (CalendarClient *client)
   for (l = client->priv->appointment_sources; l; l = l->next)
     {
       CalendarClientSource *cs = l->data;
-                  
-      if (e_cal_get_load_state (cs->source) != E_CAL_LOAD_LOADED)  
-        continue;
 
       calendar_client_start_query (client, cs, query);
     }
@@ -1621,9 +1645,6 @@ calendar_client_update_tasks (CalendarClient *client)
     {
       CalendarClientSource *cs = l->data;
 
-      if (e_cal_get_load_state (cs->source) != E_CAL_LOAD_LOADED)  
-        continue;
-
       calendar_client_start_query (client, cs, query);
     }
 
@@ -1640,8 +1661,6 @@ calendar_client_source_finalize (CalendarClientSource *source)
   source->client = NULL;
 
   if (source->source) {
-    g_signal_handlers_disconnect_by_func (source->source,
-                                          cal_opened_cb, source);
     g_object_unref (source->source);
   }
   source->source = NULL;
@@ -1676,12 +1695,12 @@ calendar_client_update_sources_list (CalendarClient *client,
       CalendarClientSource  dummy_source;
       CalendarClientSource *new_source;
       GSList               *s;
-      ECal                 *esource = link->data;
+      ECalClient           *esource = link->data;
 
       dummy_source.source = esource;
 
       dprintf ("update_sources_list: adding client %s: ",
-	       e_source_peek_uid (e_cal_get_source (esource)));
+	       e_source_peek_uid (e_client_get_source (E_CLIENT (esource))));
 
       if ((s = g_slist_find_custom (sources,
 				    &dummy_source,
@@ -1708,7 +1727,7 @@ calendar_client_update_sources_list (CalendarClient *client,
       CalendarClientSource *source = l->data;
 
       dprintf ("Removing client %s from list\n",
-	       e_source_peek_uid (e_cal_get_source (source->source)));
+	       e_source_peek_uid (e_client_get_source (E_CLIENT (source->source))));
 
       calendar_client_source_finalize (source);
       g_free (source);
@@ -2068,29 +2087,29 @@ calendar_client_set_task_completed (CalendarClient *client,
 				    gboolean        task_completed,
 				    guint           percent_complete)
 {
-  GSList              *l;
-  ECal                *esource;
-  icalcomponent       *ical;
-  icalproperty        *prop;
-  icalproperty_status  status;
+  GSList *l;
+  ECalClient *esource;
+  ICalComponent *component;
+  ICalProperty *prop;
+  ICalPropertyStatus status;
 
   g_return_if_fail (CALENDAR_IS_CLIENT (client));
   g_return_if_fail (task_uid != NULL);
   g_return_if_fail (task_completed == FALSE || percent_complete == 100);
 
-  ical = NULL;
+  component = NULL;
   esource = NULL;
   for (l = client->priv->task_sources; l; l = l->next)
     {
       CalendarClientSource *source = l->data;
 
       esource = source->source;
-      e_cal_get_object (esource, task_uid, NULL, &ical, NULL);
-      if (ical)
-	break;
+      e_cal_client_get_object_sync (esource, task_uid, NULL, &component, NULL, NULL);
+      if (component)
+        break;
     }
 
-  if (!ical)
+  if (!component)
     {
       g_warning ("Cannot locate task with uid = '%s'\n", task_uid);
       return;
@@ -2099,53 +2118,58 @@ calendar_client_set_task_completed (CalendarClient *client,
   g_assert (esource != NULL);
 
   /* Completed time */
-  prop = icalcomponent_get_first_property (ical,
-					   ICAL_COMPLETED_PROPERTY);
+  prop = i_cal_component_get_first_property (component, I_CAL_COMPLETED_PROPERTY);
   if (task_completed)
     {
-      struct icaltimetype  completed_time;
+      ICalTime *completed_time;
 
-      completed_time = icaltime_current_time_with_zone (client->priv->zone);
+      completed_time = i_cal_time_new_current_with_zone (client->priv->zone);
       if (!prop)
-	{
-	  icalcomponent_add_property (ical,
-				      icalproperty_new_completed (completed_time));
-	}
+        {
+          i_cal_component_take_property (component,
+                                         i_cal_property_new_completed (completed_time));
+        }
       else
-	{
-	  icalproperty_set_completed (prop, completed_time);
-	}
+        {
+          i_cal_property_set_completed (prop, completed_time);
+        }
     }
   else if (prop)
     {
-      icalcomponent_remove_property (ical, prop);
+      i_cal_component_remove_property (component, prop);
     }
+  g_clear_object (&prop);
 
   /* Percent complete */
-  prop = icalcomponent_get_first_property (ical,
-					   ICAL_PERCENTCOMPLETE_PROPERTY);
+  prop = i_cal_component_get_first_property (component, I_CAL_PERCENTCOMPLETE_PROPERTY);
   if (!prop)
     {
-      icalcomponent_add_property (ical,
-				  icalproperty_new_percentcomplete (percent_complete));
+      i_cal_component_take_property (component,
+                                    i_cal_property_new_percentcomplete (percent_complete));
     }
   else
     {
-      icalproperty_set_percentcomplete (prop, percent_complete);
+      i_cal_property_set_percentcomplete (prop, percent_complete);
     }
+  g_clear_object (&prop);
 
   /* Status */
-  status = task_completed ? ICAL_STATUS_COMPLETED : ICAL_STATUS_NEEDSACTION;
-  prop = icalcomponent_get_first_property (ical, ICAL_STATUS_PROPERTY);
+  status = task_completed ? I_CAL_STATUS_COMPLETED : I_CAL_STATUS_NEEDSACTION;
+  prop = i_cal_component_get_first_property (component, I_CAL_STATUS_PROPERTY);
   if (prop)
     {
-      icalproperty_set_status (prop, status);
+      i_cal_property_set_status (prop, status);
     }
   else
     {
-      icalcomponent_add_property (ical,
-				  icalproperty_new_status (status));
+      i_cal_component_take_property (component, i_cal_property_new_status (status));
     }
+  g_clear_object (&prop);
 
-  e_cal_modify_object (esource, ical, CALOBJ_MOD_ALL, NULL);
+  e_cal_client_modify_object_sync (esource,
+                                   component,
+                                   E_CAL_OBJ_MOD_ALL,
+                                   0,
+                                   NULL,
+                                   NULL);
 }
