@@ -20,6 +20,7 @@
 #include <glib/gi18n-lib.h>
 #include <libgnome-panel/gp-action.h>
 #include <libgnome-panel/gp-image-menu-item.h>
+#include <libgnome-panel/gp-utils.h>
 
 #include "gp-menu-bar-applet.h"
 #include "gp-menu-bar.h"
@@ -90,32 +91,57 @@ get_settings_menu (void)
   return g_strdup_printf ("%ssettings.menu", xdg_menu_prefx);
 }
 
+static void
+update_icon (GpApplet  *applet,
+             GtkWidget *icon)
+{
+  const char *icon_name;
+  guint icon_size;
+
+  icon_name = "start-here";
+  if (gp_applet_get_prefer_symbolic_icons (applet))
+    icon_name = "start-here-symbolic";
+
+  icon_size = gp_applet_get_panel_icon_size (applet);
+
+  gtk_image_set_from_icon_name (GTK_IMAGE (icon), icon_name, GTK_ICON_SIZE_MENU);
+  gtk_image_set_pixel_size (GTK_IMAGE (icon), icon_size);
+}
+
+static void
+prefer_symbolic_icons_cb (GpApplet   *applet,
+                          GParamSpec *pspec,
+                          GtkWidget  *icon)
+{
+  update_icon (applet, icon);
+}
+
 static void
 panel_icon_size_cb (GpApplet   *applet,
                     GParamSpec *pspec,
                     GtkWidget  *icon)
 {
-  guint icon_size;
-
-  icon_size = gp_applet_get_panel_icon_size (applet);
-  gtk_image_set_pixel_size (GTK_IMAGE (icon), icon_size);
+  update_icon (applet, icon);
 }
 
 static void
 append_applications_item (GpMenuBarApplet *applet)
 {
-  guint icon_size;
   GtkWidget *icon;
   const gchar *tooltip;
   gchar *menu;
 
-  icon_size = gp_applet_get_panel_icon_size (GP_APPLET (applet));
-  icon = gtk_image_new_from_icon_name ("start-here", GTK_ICON_SIZE_MENU);
-  gtk_image_set_pixel_size (GTK_IMAGE (icon), icon_size);
+  icon = gtk_image_new ();
+  gp_add_text_color_class (icon);
+
+  g_signal_connect (applet, "notify::prefer-symbolic-icons",
+                    G_CALLBACK (prefer_symbolic_icons_cb), icon);
 
   g_signal_connect (applet, "notify::panel-icon-size",
                     G_CALLBACK (panel_icon_size_cb), icon);
 
+  update_icon (GP_APPLET (applet), icon);
+
   applet->applications_item = gp_image_menu_item_new_with_label (_("Applications"));
   gtk_menu_shell_append (GTK_MENU_SHELL (applet->menu_bar), applet->applications_item);
   gp_image_menu_item_set_image (GP_IMAGE_MENU_ITEM (applet->applications_item), icon);
